@@ -23,7 +23,7 @@ import xml.dom.minidom
 import mimetypes
 
 PROG = os.path.basename(os.path.splitext(__file__)[0])
-VERSION = '8.6.8'
+VERSION = '8.6.9'
 
 # AsciiDoc global configuration file directory.
 # NOTE: CONF_DIR is "fixed up" by Makefile -- don't rename or change syntax.
@@ -444,12 +444,18 @@ class A2X(AttrDict):
         if not os.path.isfile(self.asciidoc_file):
             die('missing SOURCE_FILE: %s' % self.asciidoc_file)
         self.asciidoc_file = os.path.abspath(self.asciidoc_file)
+        if os.path.splitext(self.asciidoc_file)[1].lower() == '.xml':
+            self.skip_asciidoc = True
+        else:
+            self.skip_asciidoc = False
         if not self.destination_dir:
             self.destination_dir = os.path.dirname(self.asciidoc_file)
         else:
             if not os.path.isdir(self.destination_dir):
                 die('missing --destination-dir: %s' % self.destination_dir)
             self.destination_dir = os.path.abspath(self.destination_dir)
+            if not self.format in ('chunked','epub','htmlhelp','xhtml'):
+                warning('--destination-dir option is only applicable to HTML based outputs')
         self.resource_dirs = []
         self.resource_files = []
         if self.resource_manifest:
@@ -529,10 +535,6 @@ class A2X(AttrDict):
                 self.xsltproc_opts += ' --stringparam ' + o
         if self.fop_opts:
             self.fop = True
-        if os.path.splitext(self.asciidoc_file)[1].lower() == '.xml':
-            self.skip_asciidoc = True
-        else:
-            self.skip_asciidoc = False
 
     def dst_path(self, ext):
         '''
