@@ -90,6 +90,20 @@ def print_verbose(line):
     if verbose:
         print_stderr(line)
 
+def write_file(filename, data, mode='w'):
+    f = open(filename, mode)
+    try:
+        f.write(data)
+    finally:
+        f.close()
+
+def read_file(filename, mode='r'):
+    f = open(filename, mode)
+    try:
+        return f.read()
+    finally:
+        f.close()
+
 def run(cmd):
     global verbose
     if verbose:
@@ -113,17 +127,16 @@ def latex2png(infile, outfile, dpi, modified):
     skip = False
     if infile == '-':
         tex = sys.stdin.read()
-        checksum = md5.new(tex).digest()
-        f = os.path.splitext(outfile)[0] + '.md5'
         if modified:
-            if os.path.isfile(f) and os.path.isfile(outfile) and \
-                    checksum == open(f,'rb').read():
+            checksum = md5.new(tex).digest()
+            md5_file = os.path.splitext(outfile)[0] + '.md5'
+            if os.path.isfile(md5_file) and os.path.isfile(outfile) and \
+                    checksum == read_file(md5_file,'rb'):
                 skip = True
-            open(f,'wb').write(checksum)
     else:
         if not os.path.isfile(infile):
             raise EApp, 'input file does not exist: %s' % infile
-        tex = open(infile).read()
+        tex = read_file(infile)
         if modified and os.path.isfile(outfile) and \
                 os.path.getmtime(infile) <= os.path.getmtime(outfile):
             skip = True
@@ -132,7 +145,7 @@ def latex2png(infile, outfile, dpi, modified):
         return
     tex = '%s\n%s\n%s\n' % (TEX_HEADER, tex.strip(), TEX_FOOTER)
     print_verbose('tex:\n%s' % tex)
-    open(texfile, 'w').write(tex)
+    write_file(texfile, tex)
     saved_pwd = os.getcwd()
     os.chdir(outdir)
     try:
@@ -142,15 +155,18 @@ def latex2png(infile, outfile, dpi, modified):
         cmd = 'dvipng'
         if dpi:
             cmd += ' -D %s' % dpi
-        cmd += ' -T tight -x 1000 -z 9 -bg Transparent -o "%s" "%s"' \
+        cmd += ' -T tight -x 1000 -z 9 -bg Transparent --truecolor -o "%s" "%s" ' \
                % (outfile,dvifile)
         run(cmd)
     finally:
         os.chdir(saved_pwd)
-    for f in temps:
-        if os.path.isfile(f):
-            print_verbose('deleting: %s' % f)
-            os.remove(f)
+        for f in temps:
+            if os.path.isfile(f):
+                print_verbose('deleting: %s' % f)
+                os.remove(f)
+    if 'md5_file' in locals():
+        print_verbose('writing: %s' % md5_file)
+        write_file(md5_file, checksum, 'wb')
 
 def usage(msg=''):
     if msg:
